==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/LegacyGhostCellsGenerator-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_depends" "LegacyGhostCellsGeneratorFilters;VTK::CommonExecutionModel;VTK::CommonSystem;VTK::FiltersCore;VTK::FiltersGeneral;VTK::FiltersGeometry;VTK::ParallelMPI")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc;VTK::ParallelCore")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_implements" "LegacyGhostCellsGeneratorFilters")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_library_name" "LegacyGhostCellsGeneratorParallel")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_needs_autoinit" "1")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPUnstructuredGridGhostCellsGenerator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/LegacyGhostCellsGeneratorParallelModule.h")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LegacyGhostCellsGenerator/vtk/hierarchy/LegacyGhostCellsGenerator/LegacyGhostCellsGeneratorParallel-hierarchy.txt")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_optional_depends" "VTK::ParallelCore")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_implementable" "TRUE")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_library_name" "LegacyGhostCellsGeneratorFilters")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_needs_autoinit" "1")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkUnstructuredGridGhostCellsGenerator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/LegacyGhostCellsGeneratorFiltersModule.h")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LegacyGhostCellsGenerator/vtk/hierarchy/LegacyGhostCellsGenerator/LegacyGhostCellsGeneratorFilters-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/LegacyGhostCellsGenerator-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_depends" "LegacyGhostCellsGeneratorFilters;VTK::CommonExecutionModel;VTK::CommonSystem;VTK::FiltersCore;VTK::FiltersGeneral;VTK::FiltersGeometry;VTK::ParallelMPI")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc;VTK::ParallelCore")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_implements" "LegacyGhostCellsGeneratorFilters")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_library_name" "LegacyGhostCellsGeneratorParallel")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_needs_autoinit" "1")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPUnstructuredGridGhostCellsGenerator.h")
set_property(TARGET "LegacyGhostCellsGeneratorParallel" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LegacyGhostCellsGenerator/vtk/hierarchy/LegacyGhostCellsGenerator/LegacyGhostCellsGeneratorParallel-hierarchy.txt")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_optional_depends" "VTK::ParallelCore")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_implementable" "TRUE")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_library_name" "LegacyGhostCellsGeneratorFilters")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_needs_autoinit" "1")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkUnstructuredGridGhostCellsGenerator.h")
set_property(TARGET "LegacyGhostCellsGeneratorFilters" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/LegacyGhostCellsGenerator/vtk/hierarchy/LegacyGhostCellsGenerator/LegacyGhostCellsGeneratorFilters-hierarchy.txt")
unset(_vtk_module_import_prefix)
